/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.mail.service.impl.guests;

import com.openexchange.exception.OXException;
import com.openexchange.mail.Protocol;
import com.openexchange.mail.api.AbstractProtocolProperties;
import com.openexchange.mail.api.IMailFolderStorage;
import com.openexchange.mail.api.IMailMessageStorage;
import com.openexchange.mail.api.MailAccess;
import com.openexchange.mail.api.MailProvider;
import com.openexchange.mailaccount.Constants;
import com.openexchange.session.Session;

/**
 * {@link GuardGuestMailProvider} - A provider for handling OX Guard encrypted guest emails
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v7.10.0
 */
public class GuardGuestMailProvider extends MailProvider {

    private final static Protocol GUARD_GUEST_PROTOCOL = new Protocol(Constants.MAIL_PROTOCOL_GUARD_GUEST);
    private final static AbstractProtocolProperties EMPTY_PROPERTIES = new AbstractProtocolProperties() {

        @Override
        protected void resetFields() { }

        @Override
        protected void loadProperties0() throws OXException { }
    };

    /* (non-Javadoc)
     * @see com.openexchange.mail.api.MailProvider#getProtocol()
     */
    @Override
    public Protocol getProtocol() {
        return GUARD_GUEST_PROTOCOL;
    }

    /* (non-Javadoc)
     * @see com.openexchange.mail.api.MailProvider#createNewMailAccess(com.openexchange.session.Session)
     */
    @Override
    public MailAccess<?, ?> createNewMailAccess(Session session) throws OXException {
        return new GuardGuestMailAccess(session);
    }

    /* (non-Javadoc)
     * @see com.openexchange.mail.api.MailProvider#createNewMailAccess(com.openexchange.session.Session, int)
     */
    @Override
    public MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> createNewMailAccess(Session session, int accountId) throws OXException {
        return new GuardGuestMailAccess(session, accountId);
    }

    /* (non-Javadoc)
     * @see com.openexchange.mail.api.MailProvider#getProtocolProperties()
     */
    @Override
    protected AbstractProtocolProperties getProtocolProperties() {
        return EMPTY_PROPERTIES;
    }

}
